@@ -78,7 +78,7 @@ $mediaTypeFormList
 	->addRow(_('Authentication'),
 		(new CRadioButtonList('smtp_authentication', (int) $data['smtp_authentication']))
 			->addValue(_('None'), SMTP_AUTHENTICATION_NONE)
-			->addValue(_('Normal password'), SMTP_AUTHENTICATION_NORMAL)
+			->addValue(_('Username and password'), SMTP_AUTHENTICATION_NORMAL)
 			->setModern(true)
 	)
 	->addRow(_('Username'), (new CTextBox('smtp_username', $data['smtp_username']))->setWidth(ZBX_TEXTAREA_SMALL_WIDTH))
