@@ -44,10 +44,14 @@ $fields = [
 	'key' =>						[T_ZBX_STR, O_OPT, null,	NOT_EMPTY,	'isset({add}) || isset({update})',
 		_('Key')
 	],
-	'delay' =>						[T_ZBX_INT, O_OPT, null,	BETWEEN(0, SEC_PER_DAY),
+	'master_itemid' =>				[T_ZBX_STR, O_OPT, null,	null,
+		'(isset({add}) || isset({update})) && isset({type}) && {type}=='.ITEM_TYPE_DEPENDENT, _('Master item')],
+	'master_itemname' =>			[T_ZBX_STR, O_OPT, null,	null,			null],
+	'delay' =>						[T_ZBX_TU, O_OPT, P_ALLOW_USER_MACRO | P_ALLOW_LLD_MACRO, null,
 		'(isset({add}) || isset({update}))'.
-			' && (isset({type}) && ({type} != '.ITEM_TYPE_TRAPPER.' && {type} != '.ITEM_TYPE_SNMPTRAP.'))',
-		_('Update interval (in sec)')
+			' && (isset({type}) && ({type} != '.ITEM_TYPE_TRAPPER.' && {type} != '.ITEM_TYPE_SNMPTRAP.')'.
+			' && {type}!='.ITEM_TYPE_DEPENDENT.')',
+		_('Update interval')
 	],
 	'delay_flex' =>					[T_ZBX_STR, O_OPT, null,	null,			null],
 	'status' =>						[T_ZBX_INT, O_OPT, null,	IN(ITEM_STATUS_ACTIVE), null],
@@ -55,15 +59,11 @@ $fields = [
 		IN([-1, ITEM_TYPE_ZABBIX, ITEM_TYPE_SNMPV1, ITEM_TYPE_TRAPPER, ITEM_TYPE_SIMPLE, ITEM_TYPE_SNMPV2C,
 			ITEM_TYPE_INTERNAL, ITEM_TYPE_SNMPV3, ITEM_TYPE_ZABBIX_ACTIVE, ITEM_TYPE_AGGREGATE, ITEM_TYPE_EXTERNAL,
 			ITEM_TYPE_DB_MONITOR, ITEM_TYPE_IPMI, ITEM_TYPE_SSH, ITEM_TYPE_TELNET, ITEM_TYPE_JMX, ITEM_TYPE_CALCULATED,
-			ITEM_TYPE_SNMPTRAP]
+			ITEM_TYPE_SNMPTRAP, ITEM_TYPE_DEPENDENT]
 		),
 		'isset({add}) || isset({update})'
 	],
 	'value_type' =>					[T_ZBX_INT, O_OPT, null,	IN('0,1,2,3,4'), 'isset({add}) || isset({update})'],
-	'data_type' =>					[T_ZBX_INT, O_OPT, null,
-		IN(ITEM_DATA_TYPE_DECIMAL.','.ITEM_DATA_TYPE_OCTAL.','.ITEM_DATA_TYPE_HEXADECIMAL.','.ITEM_DATA_TYPE_BOOLEAN),
-		'(isset({add}) || isset({update})) && (isset({value_type}) && ({value_type} == '.ITEM_VALUE_TYPE_UINT64.'))'
-	],
 	'valuemapid' =>					[T_ZBX_INT, O_OPT, null,	DB_ID,
 		'(isset({add}) || isset({update})) && isset({value_type})'.
 			' && '.IN(ITEM_VALUE_TYPE_FLOAT.','.ITEM_VALUE_TYPE_UINT64, 'value_type')
@@ -139,21 +139,13 @@ $fields = [
 		'(isset({add}) || isset({update})) && isset({type}) && ({type} == 2)'
 	],
 	'units' =>						[T_ZBX_STR, O_OPT, null,	null,
-		'(isset({add}) || isset({update})) && isset({value_type})'.
-			' && '.IN('0,3', 'value_type').' (isset({data_type}) && ({data_type} != '.ITEM_DATA_TYPE_BOOLEAN.'))'
-	],
-	'multiplier' =>					[T_ZBX_INT, O_OPT, null,	null,		null],
-	'delta' =>						[T_ZBX_INT, O_OPT, null,	IN('0,1,2'),
-		'(isset({add}) || isset({update})) && isset({value_type})'.
-			' && '.IN('0,3', 'value_type').' (isset({data_type}) && ({data_type} != '.ITEM_DATA_TYPE_BOOLEAN.'))'
-	],
-	'formula' =>					[T_ZBX_DBL_STR, O_OPT, null,
-		'({value_type} == 0 && {} != 0) || ({value_type} == 3 && {} > 0)',
-		'(isset({add}) || isset({update})) && isset({multiplier}) && {multiplier} == 1', _('Custom multiplier')
+		'(isset({add}) || isset({update})) && isset({value_type}) && '.
+		IN(ITEM_VALUE_TYPE_FLOAT.','.ITEM_VALUE_TYPE_UINT64, 'value_type')
 	],
 	'logtimefmt' =>					[T_ZBX_STR, O_OPT, null,	null,
 		'(isset({add}) || isset({update})) && (isset({value_type}) && ({value_type} == 2))'
 	],
+	'preprocessing' =>				[T_ZBX_STR, O_OPT, P_NO_TRIM,	null,	null],
 	'group_itemid' =>				[T_ZBX_INT, O_OPT, null,	DB_ID,		null],
 	'new_application' =>			[T_ZBX_STR, O_OPT, null,	null,		'isset({add}) || isset({update})'],
 	'applications' =>				[T_ZBX_INT, O_OPT, null,	DB_ID,		null],
@@ -161,14 +153,17 @@ $fields = [
 		'isset({parent_discoveryid}) && (isset({add}) || isset({update}))'
 	],
 	'application_prototypes' =>		[T_ZBX_STR, O_OPT, null,	null,		null],
-	'history' =>					[T_ZBX_INT, O_OPT, null,	BETWEEN(0, 65535), 'isset({add}) || isset({update})',
+	'history' =>					[T_ZBX_STR, O_OPT, null,	null, 'isset({add}) || isset({update})',
 		_('History storage period')
 	],
-	'trends' =>						[T_ZBX_INT, O_OPT, null,	BETWEEN(0, 65535),
+	'trends' =>						[T_ZBX_STR, O_OPT, null,	null,
 		'(isset({add}) || isset({update})) && isset({value_type})'.
 			' && '.IN(ITEM_VALUE_TYPE_FLOAT.','.ITEM_VALUE_TYPE_UINT64, 'value_type'),
 		_('Trend storage period')
 	],
+	'jmx_endpoint' =>				[T_ZBX_STR, O_OPT, null,	NOT_EMPTY,
+		'(isset({add}) || isset({update})) && isset({type}) && {type} == '.ITEM_TYPE_JMX
+	],
 	// actions
 	'action' =>						[T_ZBX_STR, O_OPT, P_SYS|P_ACT,
 		IN('"itemprototype.massdelete","itemprototype.massdisable","itemprototype.massenable"'), null
@@ -205,8 +200,16 @@ if (!$discoveryRule) {
 }
 
 $itemPrototypeId = getRequest('itemid');
-if ($itemPrototypeId && !API::ItemPrototype()->isWritable([$itemPrototypeId])) {
-	access_deny();
+if ($itemPrototypeId) {
+	$item_prorotypes = API::ItemPrototype()->get([
+		'output' => [],
+		'itemids' => $itemPrototypeId,
+		'editable' => true
+	]);
+
+	if (!$item_prorotypes) {
+		access_deny();
+	}
 }
 
 /*
@@ -252,16 +255,18 @@ elseif (hasRequest('add') || hasRequest('update')) {
 		}
 	}
 
+	$delay = getRequest('delay', DB::getDefault('items', 'delay'));
+	$type = getRequest('type', ITEM_TYPE_ZABBIX);
+
 	/*
-	 * Intially validate "delay_flex" field one by one to make sure it does not have interval separator ";".
-	 * Skip empty fields and convert "delay_flex" array to string glued with ";" which is later validated through API.
+	 * "delay_flex" is a temporary field that collects flexible and scheduling intervals separated by a semicolon.
+	 * In the end, custom intervals together with "delay" are stored in the "delay" variable.
 	 */
-	$delay_flex = '';
-	$intervals = [];
+	if (!in_array($type, [ITEM_TYPE_ZABBIX_ACTIVE, ITEM_TYPE_TRAPPER, ITEM_TYPE_SNMPTRAP]) && hasRequest('delay_flex')) {
+		$intervals = [];
 
-	if (getRequest('delay_flex')) {
 		foreach (getRequest('delay_flex') as $interval) {
-			if ($interval['type'] == ITEM_DELAY_FLEX_TYPE_FLEXIBLE) {
+			if ($interval['type'] == ITEM_DELAY_FLEXIBLE) {
 				if ($interval['delay'] === '' && $interval['period'] === '') {
 					continue;
 				}
@@ -295,7 +300,7 @@ elseif (hasRequest('add') || hasRequest('update')) {
 		}
 
 		if ($intervals) {
-			$delay_flex = join(';', $intervals);
+			$delay .= ';'.implode(';', $intervals);
 		}
 	}
 
@@ -319,13 +324,36 @@ elseif (hasRequest('add') || hasRequest('update')) {
 			$application_prototypes[] = ['name' => $new_application_prototype];
 		}
 
+		$preprocessing = getRequest('preprocessing', []);
+
+		foreach ($preprocessing as &$step) {
+			switch ($step['type']) {
+				case ZBX_PREPROC_MULTIPLIER:
+				case ZBX_PREPROC_RTRIM:
+				case ZBX_PREPROC_LTRIM:
+				case ZBX_PREPROC_TRIM:
+				case ZBX_PREPROC_XPATH:
+				case ZBX_PREPROC_JSONPATH:
+					$step['params'] = $step['params'][0];
+					break;
+
+				case ZBX_PREPROC_REGSUB:
+					$step['params'] = implode("\n", $step['params']);
+					break;
+
+				default:
+					$step['params'] = '';
+			}
+		}
+		unset($step);
+
 		$item = [
 			'name'			=> getRequest('name'),
 			'description'	=> getRequest('description'),
 			'key_'			=> getRequest('key'),
 			'hostid'		=> $discoveryRule['hostid'],
 			'interfaceid'	=> getRequest('interfaceid'),
-			'delay'			=> getRequest('delay'),
+			'delay'			=> $delay,
 			'status'		=> getRequest('status', ITEM_STATUS_DISABLED),
 			'type'			=> getRequest('type'),
 			'snmp_community' => getRequest('snmp_community'),
@@ -334,10 +362,7 @@ elseif (hasRequest('add') || hasRequest('update')) {
 			'trapper_hosts'	=> getRequest('trapper_hosts'),
 			'port'			=> getRequest('port'),
 			'history'		=> getRequest('history'),
-			'trends'		=> getRequest('trends'),
 			'units'			=> getRequest('units'),
-			'multiplier'	=> getRequest('multiplier', 0),
-			'delta'			=> getRequest('delta'),
 			'snmpv3_contextname' => getRequest('snmpv3_contextname'),
 			'snmpv3_securityname' => getRequest('snmpv3_securityname'),
 			'snmpv3_securitylevel' => getRequest('snmpv3_securitylevel'),
@@ -345,7 +370,6 @@ elseif (hasRequest('add') || hasRequest('update')) {
 			'snmpv3_authpassphrase' => getRequest('snmpv3_authpassphrase'),
 			'snmpv3_privprotocol' => getRequest('snmpv3_privprotocol'),
 			'snmpv3_privpassphrase' => getRequest('snmpv3_privpassphrase'),
-			'formula'		=> getRequest('formula', '1'),
 			'logtimefmt'	=> getRequest('logtimefmt'),
 			'valuemapid'	=> getRequest('valuemapid'),
 			'authtype'		=> getRequest('authtype'),
@@ -355,24 +379,35 @@ elseif (hasRequest('add') || hasRequest('update')) {
 			'privatekey'	=> getRequest('privatekey'),
 			'params'		=> getRequest('params'),
 			'ipmi_sensor'	=> getRequest('ipmi_sensor'),
-			'data_type'		=> getRequest('data_type'),
-			'ruleid'		=> getRequest('parent_discoveryid'),
-			'delay_flex'	=> $delay_flex
+			'ruleid'		=> getRequest('parent_discoveryid')
 		];
 
+		if ($item['type'] == ITEM_TYPE_JMX) {
+			$item['jmx_endpoint'] = getRequest('jmx_endpoint', '');
+		}
+
+		if ($item['value_type'] == ITEM_VALUE_TYPE_FLOAT || $item['value_type'] == ITEM_VALUE_TYPE_UINT64) {
+			$item['trends'] = getRequest('trends');
+		}
+
+		if ($item['type'] == ITEM_TYPE_DEPENDENT) {
+			$item['master_itemid'] = getRequest('master_itemid');
+		}
+
 		if (hasRequest('update')) {
 			$itemId = getRequest('itemid');
 
-			$dbItem = API::ItemPrototype()->get([
-				'output' => ['type', 'snmp_community', 'snmp_oid', 'hostid', 'name', 'key_', 'delay',
-					'history', 'trends', 'status', 'value_type', 'trapper_hosts', 'units', 'multiplier', 'delta',
-					'snmpv3_securityname', 'snmpv3_securitylevel', 'snmpv3_authpassphrase', 'snmpv3_privpassphrase',
-					'formula', 'logtimefmt', 'templateid', 'valuemapid', 'delay_flex', 'params', 'ipmi_sensor',
-					'data_type', 'authtype', 'username', 'password', 'publickey', 'privatekey',	'interfaceid', 'port',
-					'description', 'snmpv3_authprotocol', 'snmpv3_privprotocol', 'snmpv3_contextname'
+			$db_item = API::ItemPrototype()->get([
+				'output' => ['type', 'snmp_community', 'snmp_oid', 'hostid', 'name', 'key_', 'delay', 'history',
+					'trends', 'status', 'value_type', 'trapper_hosts', 'units', 'snmpv3_securityname',
+					'snmpv3_securitylevel', 'snmpv3_authpassphrase', 'snmpv3_privpassphrase', 'logtimefmt',
+					'templateid', 'valuemapid', 'params', 'ipmi_sensor', 'authtype', 'username', 'password',
+					'publickey', 'privatekey', 'interfaceid', 'port', 'description', 'snmpv3_authprotocol',
+					'snmpv3_privprotocol', 'snmpv3_contextname', 'jmx_endpoint', 'master_itemid'
 				],
 				'selectApplications' => ['applicationid'],
 				'selectApplicationPrototypes' => ['name'],
+				'selectPreprocessing' => ['type', 'params'],
 				'itemids' => [$itemId]
 			]);
 
@@ -385,23 +420,23 @@ elseif (hasRequest('add') || hasRequest('update')) {
 				$item['snmpv3_privprotocol'] = ITEM_PRIVPROTOCOL_DES;
 			}
 
-			$dbItem = $dbItem[0];
+			$db_item = $db_item[0];
 
-			$item = CArrayHelper::unsetEqualValues($item, $dbItem);
+			$item = CArrayHelper::unsetEqualValues($item, $db_item);
 			$item['itemid'] = $itemId;
 
-			$dbItem['applications'] = zbx_objectValues($dbItem['applications'], 'applicationid');
+			$db_item['applications'] = zbx_objectValues($db_item['applications'], 'applicationid');
 
 			// compare applications
-			natsort($dbItem['applications']);
+			natsort($db_item['applications']);
 			natsort($applications);
 
-			if (array_values($dbItem['applications']) !== array_values($applications)) {
+			if (array_values($db_item['applications']) !== array_values($applications)) {
 				$item['applications'] = $applications;
 			}
 
 			// compare application prototypes
-			$db_application_prototype_names = zbx_objectValues($dbItem['applicationPrototypes'], 'name');
+			$db_application_prototype_names = zbx_objectValues($db_item['applicationPrototypes'], 'name');
 			natsort($db_application_prototype_names);
 
 			$application_prototype_names = zbx_objectValues($application_prototypes, 'name');
@@ -411,12 +446,20 @@ elseif (hasRequest('add') || hasRequest('update')) {
 				$item['applicationPrototypes'] = $application_prototypes;
 			}
 
+			if ($db_item['preprocessing'] !== $preprocessing) {
+				$item['preprocessing'] = $preprocessing;
+			}
+
 			$result = API::ItemPrototype()->update($item);
 		}
 		else {
 			$item['applications'] = $applications;
 			$item['applicationPrototypes'] = $application_prototypes;
 
+			if ($preprocessing) {
+				$item['preprocessing'] = $preprocessing;
+			}
+
 			$result = API::ItemPrototype()->create($item);
 		}
 	}
@@ -474,23 +517,66 @@ elseif (hasRequest('action') && getRequest('action') == 'itemprototype.massdelet
  */
 if (isset($_REQUEST['form'])) {
 	$itemPrototype = [];
+	$has_errors = false;
+	$master_prototype_options = [];
+
 	if (hasRequest('itemid')) {
 		$itemPrototype = API::ItemPrototype()->get([
 			'itemids' => getRequest('itemid'),
 			'output' => [
 				'itemid', 'type', 'snmp_community', 'snmp_oid', 'hostid', 'name', 'key_', 'delay', 'history',
-				'trends', 'status', 'value_type', 'trapper_hosts', 'units', 'multiplier', 'delta',
-				'snmpv3_securityname', 'snmpv3_securitylevel', 'snmpv3_authpassphrase', 'snmpv3_privpassphrase',
-				'formula', 'logtimefmt', 'templateid', 'valuemapid', 'delay_flex', 'params', 'ipmi_sensor',
-				'data_type', 'authtype', 'username', 'password', 'publickey', 'privatekey', 'interfaceid', 'port',
-				'description', 'snmpv3_authprotocol', 'snmpv3_privprotocol', 'snmpv3_contextname'
-			]
+				'trends', 'status', 'value_type', 'trapper_hosts', 'units', 'snmpv3_securityname',
+				'snmpv3_securitylevel', 'snmpv3_authpassphrase', 'snmpv3_privpassphrase', 'logtimefmt', 'templateid',
+				'valuemapid', 'params', 'ipmi_sensor', 'authtype', 'username', 'password', 'publickey', 'privatekey',
+				'interfaceid', 'port', 'description', 'snmpv3_authprotocol', 'snmpv3_privprotocol',
+				'snmpv3_contextname', 'jmx_endpoint', 'master_itemid'
+			],
+			'selectPreprocessing' => ['type', 'params']
 		]);
 		$itemPrototype = reset($itemPrototype);
+		foreach ($itemPrototype['preprocessing'] as &$step) {
+			$step['params'] = explode("\n", $step['params']);
+		}
+		unset($step);
+
+		if ($itemPrototype['type'] == ITEM_TYPE_DEPENDENT) {
+			$master_prototype_options = [
+				'itemids' => $itemPrototype['master_itemid'],
+				'output' => ['itemid', 'type', 'hostid', 'name', 'key_']
+			];
+		}
+	}
+	elseif (getRequest('master_itemid') && getRequest('parent_discoveryid')) {
+		$discovery_rule = API::DiscoveryRule()->get([
+			'output' => ['hostid'],
+			'itemids' => getRequest('parent_discoveryid'),
+			'editable' => true
+		]);
+
+		if ($discovery_rule) {
+			$master_prototype_options = [
+				'itemids' => getRequest('master_itemid'),
+				'output' => ['itemid', 'type', 'hostid', 'name', 'key_'],
+				'filter' => ['hostid' => $discovery_rule[0]['hostid']]
+			];
+		}
+	}
+
+	if ($master_prototype_options) {
+		$master_prototypes = API::ItemPrototype()->get($master_prototype_options);
+
+		if ($master_prototypes) {
+			$itemPrototype['master_item'] = reset($master_prototypes);
+		}
+		else {
+			show_messages(false, '', _('No permissions to referred object or it does not exist!'));
+			$has_errors = true;
+		}
 	}
 
 	$data = getItemFormData($itemPrototype);
 	$data['config'] = select_config();
+	$data['trends_default'] = DB::getDefault('items', 'trends');
 
 	// Sort interfaces to be listed starting with one selected as 'main'.
 	CArrayHelper::sort($data['interfaces'], [
@@ -498,9 +584,11 @@ if (isset($_REQUEST['form'])) {
 	]);
 
 	// render view
-	$itemView = new CView('configuration.item.prototype.edit', $data);
-	$itemView->render();
-	$itemView->show();
+	if (!$has_errors) {
+		$itemView = new CView('configuration.item.prototype.edit', $data);
+		$itemView->render();
+		$itemView->show();
+	}
 }
 else {
 	$sortField = getRequest('sort', CProfile::get('web.'.$page['file'].'.sort', 'name'));
@@ -528,21 +616,24 @@ else {
 		'limit' => $config['search_limit'] + 1
 	]);
 
-	foreach ($data['items'] as &$item) {
-		if ($item['value_type'] == ITEM_VALUE_TYPE_STR || $item['value_type'] == ITEM_VALUE_TYPE_LOG
-				|| $item['value_type'] == ITEM_VALUE_TYPE_TEXT) {
-			$item['trends'] = '';
-		}
+	$data['items'] = expandItemNamesWithMasterItems($data['items'], API::ItemPrototype());
 
-		if ($item['type'] == ITEM_TYPE_TRAPPER || $item['type'] == ITEM_TYPE_SNMPTRAP) {
-			$item['delay'] = '';
-		}
+	switch ($sortField) {
+		case 'delay':
+			orderItemsByDelay($data['items'], $sortOrder, ['usermacros' => true, 'lldmacros' => true]);
+			break;
+
+		case 'history':
+			orderItemsByHistory($data['items'], $sortOrder);
+			break;
+
+		case 'trends':
+			orderItemsByTrends($data['items'], $sortOrder);
+			break;
+
+		default:
+			order_result($data['items'], $sortField, $sortOrder);
 	}
-	unset($item);
-
-	$data['items'] = CMacrosResolverHelper::resolveItemNames($data['items']);
-
-	order_result($data['items'], $sortField, $sortOrder);
 
 	$url = (new CUrl('disc_prototypes.php'))
 		->setArgument('parent_discoveryid', $data['parent_discoveryid']);
