@@ -107,7 +107,7 @@ class CLineGraphDraw extends CGraphDraw {
 		if ($this->type == GRAPH_TYPE_STACKED) {
 			$graph_item['drawtype'] = GRAPH_ITEM_DRAWTYPE_FILLED_REGION;
 		}
-		$update_interval_parser = new CUpdateIntervalParser();
+		$update_interval_parser = new CUpdateIntervalParser(['usermacros' => true]);
 
 		if ($update_interval_parser->parse($graph_item['delay']) != CParser::PARSE_SUCCESS) {
 			show_error_message(_s('Incorrect value for field "%1$s": %2$s.', 'delay', _('invalid delay')));
@@ -1910,7 +1910,7 @@ class CLineGraphDraw extends CGraphDraw {
 			$this->to_time = $this->stime + $this->period;
 		}
 		else {
-			$this->to_time = $now - SEC_PER_HOUR * $this->from;
+			$this->to_time = $now;
 			$this->from_time = $this->to_time - $this->period;
 		}
 
@@ -2737,6 +2737,16 @@ class CLineGraphDraw extends CGraphDraw {
 
 		$maxX = $this->sizeX;
 
+		if ($this->dataFrom === 'trends') {
+			// Correct item 'delay' field value when graph data requested for trends.
+			foreach ($this->items as &$item) {
+				if (!$item['has_scheduling_intervals'] || $item['delay'] != 0) {
+					$item['delay'] = max($item['delay'], SEC_PER_HOUR);
+				}
+			}
+			unset($item);
+		}
+
 		// for each metric
 		for ($item = 0; $item < $this->num; $item++) {
 			$minY = $this->m_minY[$this->items[$item]['yaxisside']];
