@@ -42,6 +42,11 @@ $menu = (new CList())
 		SPACE.'/'.SPACE,
 		(new CButton('linkRemove', _('Remove')))->addClass(ZBX_STYLE_BTN_LINK)
 	])
+	->addItem([
+		_('Expand macros').':'.SPACE,
+		(new CButton('expand_macros', ($this->data['sysmap']['expand_macros'] == SYSMAP_EXPAND_MACROS_ON)
+				? _('On') : _('Off')))->addClass(ZBX_STYLE_BTN_LINK)
+	])
 	->addItem([
 		_('Grid').':'.SPACE,
 		(new CButton('gridshow',
