@@ -107,8 +107,14 @@
 			// timeline params
 			// SCREEN_RESOURCE_HTTPTEST_DETAILS, SCREEN_RESOURCE_DISCOVERY, SCREEN_RESOURCE_HTTPTEST
 			if (jQuery.inArray(screen.resourcetype, [21, 22, 23]) === -1) {
-				ajaxUrl.setArgument('period', empty(screen.timeline.period) ? null : screen.timeline.period);
+				if (!empty(timeControl.timeline)) {
+					timeControl.timeline.refreshEndtime();
+				}
+				ajaxUrl.setArgument('period', empty(screen.timeline.period) ? null : this.getCalculatedPeriod(screen));
 				ajaxUrl.setArgument('stime', this.getCalculatedSTime(screen));
+				if (typeof screen.timeline.isNow !== 'undefined') {
+					ajaxUrl.setArgument('isNow', + screen.timeline.isNow);
+				}
 			}
 
 			// SCREEN_RESOURCE_GRAPH or SCREEN_RESOURCE_SIMPLE_GRAPH
@@ -119,8 +125,14 @@
 							var obj = $(this),
 								url = new Curl(obj.attr('href'));
 
-							url.setArgument('period', empty(screen.timeline.period) ? null : screen.timeline.period);
+							url.setArgument('period', empty(screen.timeline.period)
+								? null
+								: window.flickerfreeScreen.getCalculatedPeriod(screen)
+							);
 							url.setArgument('stime', window.flickerfreeScreen.getCalculatedSTime(screen));
+							if (typeof screen.timeline.isNow !== 'undefined') {
+								url.setArgument('isNow', + screen.timeline.isNow);
+							}
 							obj.attr('href', url.getUrl());
 						});
 					});
@@ -283,6 +295,10 @@
 							window.flickerfreeScreenShadow.fadeSpeed(id, 0);
 							window.flickerfreeScreenShadow.validate(id);
 						}
+						else if (!html.length) {
+							$('#flickerfreescreen_' + id).remove();
+						}
+
 						chkbxRange.init();
 					},
 					error: function() {
@@ -350,10 +366,17 @@
 						on_dashboard = timeControl.objectList[id].onDashboard;
 
 					url.setArgument('screenid', empty(screen.screenid) ? null : screen.screenid);
-					url.setArgument('updateProfile', (typeof screen.updateProfile === 'undefined')
-						? null : + screen.updateProfile);
-					url.setArgument('period', empty(screen.timeline.period) ? null : screen.timeline.period);
+					if (typeof screen.updateProfile === 'undefined') {
+						url.setArgument('updateProfile', + screen.updateProfile);
+					}
+					url.setArgument('period', empty(screen.timeline.period)
+						? null
+						: window.flickerfreeScreen.getCalculatedPeriod(screen)
+					);
 					url.setArgument('stime', window.flickerfreeScreen.getCalculatedSTime(screen));
+					if (typeof screen.timeline.isNow !== 'undefined') {
+						url.setArgument('isNow', + screen.timeline.isNow);
+					}
 					url.setArgument('curtime', new CDate().getTime());
 
 					// Create temp image in buffer.
@@ -502,31 +525,22 @@
 		},
 
 		getCalculatedSTime: function(screen) {
-			if (!empty(timeControl.timeline) && screen.timeline.period > timeControl.timeline.maxperiod) {
-				return new CDate(timeControl.timeline.starttime() * 1000).getZBXDate();
+			if (timeControl.timeline && timeControl.timeline.is_selectall_period) {
+				return timeControl.timeline.usertime();
 			}
 
-			return (screen.timeline.isNow || screen.timeline.isNow == 1)
-				// 31536000 = 86400 * 365 = 1 year
-				? new CDate((new CDate().setZBXDate(screen.timeline.stime) / 1000 + 31536000) * 1000).getZBXDate()
-				: screen.timeline.stime;
+			return screen.timeline.stime;
 		},
 
-		submitForm: function(formName) {
-			var period = '',
-				stime = '';
-
-			for (var id in this.screens) {
-				if (!empty(this.screens[id])) {
-					period = this.screens[id].timeline.period;
-					stime = this.getCalculatedSTime(this.screens[id]);
-					break;
-				}
-			}
-
-			$('form[name=' + formName + ']').append('<input type="hidden" name="period" value="' + period + '" />');
-			$('form[name=' + formName + ']').append('<input type="hidden" name="stime" value="' + stime + '" />');
-			$('form[name=' + formName + ']').submit();
+		/**
+		 * Return period in seconds for requesting data. Automatically calculates period when 'All' period is selected.
+		 *
+		 * @property {Object} screen screen object
+		 *
+		 * @return {int}
+		 */
+		getCalculatedPeriod: function (screen) {
+			return !empty(timeControl.timeline) ? timeControl.timeline.period() : screen.timeline.period;
 		},
 
 		cleanAll: function() {
@@ -591,7 +605,9 @@
 		end: function(id) {
 			var screen = window.flickerfreeScreen.screens[id];
 
-			if (!empty(screen) && (screen.timestamp + this.timeout) >= screen.timestampActual) {
+			if (typeof this.timers[id] !== 'undefined' && !empty(screen)
+					&& (screen.timestamp + this.timeout) >= screen.timestampActual
+			) {
 				var timer = this.timers[id];
 				timer.inUpdate = false;
 
